@@ -26,8 +26,7 @@ try:
 except ImportError:
     Qty = None
 
-from ..chemistry import Atom
-from ..tools.refdata import CCbond
+#from ..chemistry import Atom
 
 #param_units = {}
 
@@ -37,6 +36,12 @@ __all__ = ['Fullerene']
 class Fullerene(object):
     u"""Class for creating interactive Fullerene objects.
 
+    The `fullerene isomer data
+    <http://www.nanotube.msu.edu/fullerene/fullerene-isomers.html>`_
+    were downloaded from the
+    `The Nanotube Site <http://www.nanotube.msu.edu>`_
+    at `Michigan State University <http://www.msu.edu>`_.
+
     Parameters
     ----------
     verbose : bool, optional
